@@ -7,6 +7,8 @@ import yaml
 from io import BytesIO
 from tabulate import tabulate
 from termcolor import colored
+import pkg_resources  # to retrieve the package version
+
 
 def init_profile(profile, name=None):
     repo_url = 'https://github.com/emtechstack/infra-profiles/archive/refs/heads/main.zip'
@@ -67,8 +69,11 @@ def start_api():
 def stop_api():
     print("API stopped (implement actual stop logic as needed)")
 
-def build_env(name):
+def build_env(name=None):
     try:
+        if name is None:
+            name = os.path.basename(os.getcwd())
+        
         # Create the Conda environment
         subprocess.run(['conda', 'create', '-n', name, 'python=3.8', '-y'], check=True)
         print(f"Conda environment '{name}' created")
@@ -84,9 +89,11 @@ def build_env(name):
         with open(script_path, 'w') as script_file:
             script_file.write(script_content)
 
-        # Make the script executable and run it
-        subprocess.run(['chmod', '+x', script_path], check=True)
-        subprocess.run(['./' + script_path], check=True)
+        # Make the script executable
+        os.chmod(script_path, 0o775)
+
+        # Run the script using /bin/bash
+        subprocess.run(['/bin/bash', script_path], check=True)
         
         # Clean up the temporary script
         os.remove(script_path)
@@ -97,6 +104,7 @@ def build_env(name):
     except subprocess.CalledProcessError as e:
         print(f"An error occurred while building the environment: {e}")
 
+
 def display_services():
     try:
         with open('docker-compose.yml', 'r') as file:
@@ -108,10 +116,19 @@ def display_services():
         for service, details in services.items():
             ports = details.get('ports', [])
             for port in ports:
-                table_data.append([service, port])
+                table_data.append([service, port.split(':')[0], port.split(':')[1]])
         
         if table_data:
-            print(colored(tabulate(table_data, headers=['Service', 'Port'], tablefmt='grid'), 'green'))
+            # Retrieve the package version
+            version = pkg_resources.get_distribution('emtechstack').version
+            
+            # Print the title
+            title = colored(f"EmTechStack AI Dev Tools (Version {version})", 'cyan', attrs=['bold'])
+            print(title)
+            print("=" * len(title))
+            
+            # Print the table
+            print(colored(tabulate(table_data, headers=['Service', 'Port Local', 'Port Docker'], tablefmt='grid'), 'green'))
         else:
             print(colored("No services found in the docker-compose.yml file.", 'red'))
     
@@ -119,6 +136,8 @@ def display_services():
         print(colored("docker-compose.yml file not found.", 'red'))
     except yaml.YAMLError as exc:
         print(colored(f"Error reading docker-compose.yml file: {exc}", 'red'))
+    except pkg_resources.DistributionNotFound:
+        print(colored("emtechstack package not found. Ensure it is installed properly.", 'red'))
 
 def clean_code():
     subprocess.run(['black', '.'], check=True)
\ No newline at end of file
